package com.simaek.util;

import org.junit.jupiter.api.BeforeAll;
import org.junit.jupiter.api.Test;

import java.security.KeyPair;

import static org.junit.jupiter.api.Assertions.assertEquals;
import static org.junit.jupiter.api.Assertions.assertTrue;

/**
 * 测试RSA加密工具类的加密和解密功能，签名和校验功能
 *
 * @author Yaser Hsueh
 * @see com.simaek.util.RSAUtil
 */
class RSAUtilTest {
    private static String publicKeyString;
    private static String privateKeyString;

    @BeforeAll
    static void before() throws Exception {
        final KeyPair keyPair = RSAUtil.getKeyPair();
        publicKeyString = RSAUtil.getPublicKey(keyPair);
        privateKeyString = RSAUtil.getPrivateKey(keyPair);
    }

    @Test
    void encryptAndDecrypt() throws Exception {
        final String origin = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
        final byte[] bytes = RSAUtil.publicEncrypt(origin.getBytes(), RSAUtil.string2PublicKey(publicKeyString));
        final String base64 = RSAUtil.byte2Base64(bytes);
        final byte[] decrypt = RSAUtil.privateDecrypt(RSAUtil.base642Byte(base64), RSAUtil.string2PrivateKey(privateKeyString));
        final String result = new String(decrypt);
        System.out.println("Original: " + origin);
        System.out.println("Encrypted: " + base64);
        System.out.println("Decrypted: " + result);
        assertEquals(origin, result);
    }

    @Test
    void signAndVerify() throws Exception {
        final String origin = "ABCDEFGHIJKLMNOPQRSTUVWXYZ";
        final String sign = RSAUtil.privateSign(origin.getBytes(), privateKeyString);
        final boolean verify = RSAUtil.publicVerify(origin.getBytes(), publicKeyString, sign);
        System.out.println("Original: " + origin);
        System.out.println("Signature: " + sign);
        assertTrue(verify);
    }
}